@@ -8,9 +8,9 @@ require Msql::Statement;
 $QUIET  = $QUIET  = '';
 @ISA    = @ISA    = '';
 @EXPORT = @EXPORT = '';
-$VERSION = $VERSION = "1.1807";
+$VERSION = $VERSION = "1.1809";
 
-# $Revision: 1.1806 $$Date: 1997/09/03 22:37:01 $$RCSfile: Msql.pm,v $
+# $Revision: 1.1809 $$Date: 1997/09/12 18:30:25 $$RCSfile: Msql.pm,v $
 
 $QUIET = 0;
 
@@ -59,8 +59,8 @@ sub AUTOLOAD {
     my $meth = $AUTOLOAD;
     my $converted = 0;
 
-    if ($meth =~ /(.*)::/) {
-	$meth = $';
+    if ($meth =~ /(.*)::(.*)/) {
+	$meth = $2;
 	$class = $1;
     } else {
 	$class = "main";
@@ -107,7 +107,7 @@ Msql / Mysql - Perl interfaces to the mSQL and mysql databases
 
 =head1 SYNOPSIS
 
-  use Msql;
+  use Mysql;
 	
   $dbh = Msql->connect;
   $dbh = Msql->connect($host);
